@@ -70,9 +70,10 @@ setClass(Class="crp.CSFP",
               changes.crp.CSFP.rc.vares="logical",
               changes.crp.CSFP.rc.sd="logical",
               changes.crp.export="logical",
-              file.format="character"),
-	   prototype=prototype( PATH.IN="C:\\",                                                            #define default values
-					PATH.OUT="C:\\",
+              file.format="character",
+              input="list"),
+	   prototype=prototype( PATH.IN="C:/",                                                            #define default values
+					PATH.OUT="C:/",
 					PORT.NAME="portfolio.csv",
 					RISK.NAME="rating_pd.csv",
 					PDVAR.NAME="pd_sector_var.csv",
@@ -80,7 +81,7 @@ setClass(Class="crp.CSFP",
 					LOSS.UNIT=1e6,
 					NITER.MAX=0.9999,
           NITER.MAX.GLOBAL=1e5,                
-					ALPHA=c(0.9995),
+					ALPHA=c(0.999),
 					PLOT.PDF=TRUE,
 					CALC.RISK.CONT=FALSE,
 					rating=0,
@@ -141,7 +142,8 @@ setClass(Class="crp.CSFP",
           changes.crp.CSFP.rc.vares=FALSE,
           changes.crp.CSFP.rc.sd=FALSE,
           changes.crp.export=FALSE,
-          file.format="csv")
+          file.format="csv",
+          input=list())
 )
 
 setGeneric("crp.read",function(this) standardGeneric("crp.read"))
@@ -159,11 +161,19 @@ setMethod("crp.read",c("crp.CSFP"),function(this) {
 # ---------------------------------------------------------------------------------------
   
   cat("Importing risk information (Rating, PD, SD)....\n")
-  if(file.exists(paste(this@PATH.IN,this@RISK.NAME,sep=""))==TRUE){                                  # check if the file exists
+  if(nrow(this@input$risk.matrix)>0)
+    RISK.MATRIX=this@input$risk.matrix
+  else if(file.exists(paste(this@PATH.IN,this@RISK.NAME,sep=""))==TRUE){                                  # check if the file exists
     if(this@file.format=="csv")
       RISK.MATRIX=read.csv(paste(this@PATH.IN,this@RISK.NAME,sep=""),header=TRUE)
     else if(this@file.format=="csv2")
       RISK.MATRIX=read.csv2(paste(this@PATH.IN,this@RISK.NAME,sep=""),header=TRUE)
+  }
+  else{
+    cat(paste("ERROR: The ",this@RISK.NAME," file is missing!!!\n",sep=""))
+    ERROR=ERROR+1
+  }
+  if(ERROR==0){
     if(is.null(RISK.MATRIX$RATING)){
       cat("The RATING-column in ",this@RISK.NAME," is missing.")
       ERROR=ERROR+1
@@ -185,17 +195,16 @@ setMethod("crp.read",c("crp.CSFP"),function(this) {
         this@rating.SD=RISK.MATRIX$SD
     }
     remove(RISK.MATRIX)
+    this@input$risk.matrix=data.frame()
+    
+    i=which(this@rating==0)
+    if(length(i)>0){
+      this@rating=this@rating[-i]
+      this@rating.PD=this@rating.PD[-i]
+      this@rating.SD=this@rating.SD[-i]
+    }
   }
-  else{
-	  cat(paste("ERROR: The ",this@RISK.NAME," file is missing!!!\n",sep=""))
-    ERROR=ERROR+1
-  }
-  i=which(this@rating==0)
-  if(length(i)>0){
-    this@rating=this@rating[-i]
-    this@rating.PD=this@rating.PD[-i]
-    this@rating.SD=this@rating.SD[-i]
-  }
+    
    
 
 
@@ -204,11 +213,19 @@ setMethod("crp.read",c("crp.CSFP"),function(this) {
 # ---------------------------------------------------------------------------------------
 
   cat("Importing portfolio data....\n")
-  if(file.exists(paste(this@PATH.IN,this@PORT.NAME,sep=""))==TRUE){                                  # check if file exists
+  if(nrow(this@input$portfolio)>0)
+    PORTFOLIO=this@input$portfolio
+  else if(file.exists(paste(this@PATH.IN,this@PORT.NAME,sep=""))==TRUE){                                  # check if file exists
     if(this@file.format=="csv")
    	  PORTFOLIO=read.csv(paste(this@PATH.IN,this@PORT.NAME,sep=""),header=TRUE)
     else if(this@file.format=="csv2")
       PORTFOLIO=read.csv2(paste(this@PATH.IN,this@PORT.NAME,sep=""),header=TRUE)
+  }
+  else{
+   cat(paste("ERROR: The ",this@PORT.NAME," file is missing!!!\n"),sep="")
+   ERROR=ERROR+1
+  }
+  if(ERROR==0){
     this@NS=length(PORTFOLIO)-6                                                                      # assigne data to attributes
 
     if(is.null(PORTFOLIO$CPnumber)){
@@ -243,42 +260,37 @@ setMethod("crp.read",c("crp.CSFP"),function(this) {
       ERROR=ERROR+1
     }
     else{
-      remove(PORTFOLIO)                                                                                
+      remove(PORTFOLIO)
+      this@input$portfolio=data.frame()
       if(this@NS==1)
         TEMP=matrix(ncol=1,TEMP)                                                                       # convert to matrix
       this@W=cbind(1-apply(TEMP,1,sum),TEMP)                                                           # attache idiosyncratic weights as first column
       remove(TEMP)
+    }   
+    emptyCP=0
+    l=0
+    for(i in 1:this@NC){
+      if(this@CP.RATING[i]==0){
+        l=l+1
+        emptyCP[l]=i
+      }
+      else if(this@NEX[i]==0 || this@rating.PD[this@CP.RATING[i]]==0 || this@LGD[i]==0){
+        l=l+1
+        emptyCP[l]=i
+      }
     }
-   }
-   else{
-	 cat(paste("ERROR: The ",this@PORT.NAME," file is missing!!!\n"),sep="")
-      ERROR=ERROR+1
-   }
-   
-   
-   emptyCP=0
-   l=0
-   for(i in 1:this@NC){
-     if(this@CP.RATING[i]==0){
-       l=l+1
-       emptyCP[l]=i
-     }
-     else if(this@NEX[i]==0 || this@rating.PD[this@CP.RATING[i]]==0 || this@LGD[i]==0){
-       l=l+1
-       emptyCP[l]=i
-     }
-   }
-   if(l>0){
-     this@CP.NR=this@CP.NR[-emptyCP]
-     this@CP.RATING=this@CP.RATING[-emptyCP]
-     this@NEX=this@NEX[-emptyCP]
-     this@LGD=this@LGD[-emptyCP]
-     this@W=this@W[-emptyCP,]
-     this@NC=this@NC-l
-   }
-   
-   cat(this@NS,"sectors ...")
-   cat(this@NC,"counterparties (",l," removed) ... OK\n",sep="")
+    if(l>0){
+      this@CP.NR=this@CP.NR[-emptyCP]
+      this@CP.RATING=this@CP.RATING[-emptyCP]
+      this@NEX=this@NEX[-emptyCP]
+      this@LGD=this@LGD[-emptyCP]
+      this@W=this@W[-emptyCP,]
+      this@NC=this@NC-l
+    }
+     
+    cat(this@NS,"sectors ...")
+    cat(this@NC,"counterparties (",l," removed) ... OK\n",sep="")
+  }
    
    
 # --------------------------------------------------------------------------------------
@@ -286,30 +298,34 @@ setMethod("crp.read",c("crp.CSFP"),function(this) {
 # ---------------------------------------------------------------------------------------
 
    if(this@SEC.VAR.EST==5){                                                                          # sector variances are just needed if SEC.VAR.EST=5, otherwise they are calculated out of rating.SD
-   	cat("Importing PD sector variances....\n")   
-      if(file.exists(paste(this@PATH.IN,this@PDVAR.NAME,sep=""))==TRUE){                             # check if file exists
+   	 cat("Importing PD sector variances....\n")   
+     if(nrow(this@input$sec.var)>0)
+       SEC.VAR=this@input$sec.var
+     else if(file.exists(paste(this@PATH.IN,this@PDVAR.NAME,sep=""))==TRUE){                             # check if file exists
         if(this@file.format=="csv")
    		    SEC.VAR=read.csv(paste(this@PATH.IN,this@PDVAR.NAME,sep=""),header=TRUE)
         else if(this@file.format=="csv2")
           SEC.VAR=read.csv2(paste(this@PATH.IN,this@PDVAR.NAME,sep=""),header=TRUE)
-        if(is.null(SEC.VAR$Var)){
-          cat("The Var-column in ",this@PDVAR.NAME," is missing.\n")
+     }
+   	 else{
+   	   cat(paste("ERROR: The ",this@PDVAR.NAME," file is missing!!!\n",sep=""))
+   	   ERROR=ERROR+1
+   	 }
+    if(ERROR==0){
+      if(is.null(SEC.VAR$Var)){
+        cat("The Var-column in ",this@PDVAR.NAME," is missing.\n")
         ERROR=ERROR+1
-        }
-        else if(length(SEC.VAR$Var)<this@NS){
-          cat("ERROR: Number of sector variances specified in ",this@PDVAR.NAME," (",length(SEC.VAR$Var),") is smaller then the number of sectors (",this@NS,").\n",sep="")
-          ERROR=ERROR+1
-        }
-        else{
-   		    this@SEC.VAR=SEC.VAR$Var
-   		    remove(SEC.VAR)
-        }
-   		}
-   	  else{
-		    cat(paste("ERROR: The ",this@PDVAR.NAME," file is missing!!!\n",sep=""))
+      }
+      else if(length(SEC.VAR$Var)<this@NS){
+        cat("ERROR: Number of sector variances specified in ",this@PDVAR.NAME," (",length(SEC.VAR$Var),") is smaller then the number of sectors (",this@NS,").\n",sep="")
         ERROR=ERROR+1
-   	  }
-               
+      }
+      else{
+   		  this@SEC.VAR=SEC.VAR$Var
+   		  remove(SEC.VAR)
+        this@input$sec.var=data.frame()
+      }
+    }
    }
    if(this@SEC.VAR.EST<5)
 	   this@SEC.VAR=0
@@ -589,8 +605,8 @@ setMethod(f="crp.CSFP.loss",signature=c("crp.CSFP"),definition=function(this){
 
   cat("Exporting loss distribution...\n")
   FILE.TITLE="LOSSDIST"
-  FILE.NAME=paste(this@PATH.OUT,this@NAME,"\\",FILE.TITLE,".csv",sep="")
-  dir.create(paste(this@PATH.OUT,this@NAME,"\\",sep=""),showWarnings=FALSE)
+  FILE.NAME=paste(this@PATH.OUT,this@NAME,"/",FILE.TITLE,".csv",sep="")
+  dir.create(paste(this@PATH.OUT,this@NAME,"/",sep=""),showWarnings=FALSE)
   if(this@file.format=="csv")
     write.csv(matrix(cbind(this@LOSS,this@PDF,this@CDF),nrow=this@M+1,ncol=3,dimnames=list(1:length(this@PDF),c("Loss","pdf","cdf"))), file=FILE.NAME,row.names=FALSE)
   else if(this@file.format=="csv2")
@@ -1022,11 +1038,11 @@ setMethod(f="crp.export",signature=c("crp.CSFP"),definition=function(this){
   
   
   FILE.TITLE="RC"# File name of loss distribution
-  dir.create(paste(this@PATH.OUT,this@NAME,"\\",sep=""),showWarnings=FALSE)
+  dir.create(paste(this@PATH.OUT,this@NAME,"/",sep=""),showWarnings=FALSE)
   if(this@file.format=="csv")
-    write.csv(RC, file=paste(this@PATH.OUT,this@NAME,"\\",FILE.TITLE,".csv",sep=""),row.names=FALSE)
+    write.csv(RC, file=paste(this@PATH.OUT,this@NAME,"/",FILE.TITLE,".csv",sep=""),row.names=FALSE)
   else if(this@file.format=="csv2")
-    write.csv2(RC, file=paste(this@PATH.OUT,this@NAME,"\\",FILE.TITLE,".csv",sep=""),row.names=FALSE)
+    write.csv2(RC, file=paste(this@PATH.OUT,this@NAME,"/",FILE.TITLE,".csv",sep=""),row.names=FALSE)
   cat("Done....\n")
   remove(RC)
   
@@ -1107,11 +1123,11 @@ setMethod(f="crp.write.summary",signature=c("crp.CSFP"),definition=function(this
     
   if(deparse(substitute(this))!="this")
         this@NAME=deparse(substitute(this))
-  dir.create(paste(this@PATH.OUT,this@NAME,"\\",sep=""),showWarnings=FALSE)
+  dir.create(paste(this@PATH.OUT,this@NAME,"/",sep=""),showWarnings=FALSE)
   if(this@file.format=="csv")
-    write.csv(crp.summary(this),paste(this@PATH.OUT,this@NAME,"\\summary.csv",sep=""),row.names=FALSE)
+    write.csv(crp.summary(this),paste(this@PATH.OUT,this@NAME,"/summary.csv",sep=""),row.names=FALSE)
   else if(this@file.format=="csv2")
-    write.csv2(crp.summary(this),paste(this@PATH.OUT,this@NAME,"\\summary.csv",sep=""),row.names=FALSE)
+    write.csv2(crp.summary(this),paste(this@PATH.OUT,this@NAME,"/summary.csv",sep=""),row.names=FALSE)
 
   return(this)
 }
@@ -1244,6 +1260,35 @@ setMethod(f="crp.set.changes",signature=c("character","crp.CSFP"),definition=fun
   }
   return(this)
 })
+
+
+setMethod("show", signature = "crp.CSFP", definition = function(object){
+  
+  if(any(object@changes.crp.read,object@changes.crp.plausi,object@changes.crp.calc.portfolio.statistics,object@changes.crp.CSFP.loss,object@changes.crp.measure,object@changes.crp.plot,object@changes.crp.CSFP.rc.vares,object@changes.crp.CSFP.rc.sd,object@changes.crp.export))
+    cat("WARNING: Input parameters have been changed without recalculation of the model. Displayed results may be incorrect.\n")
+  S=crp.summary(object)
+  cat("Model name:",S$NAME,"\n")
+  cat("Number of counterparties:",S$NC,"\n")
+  cat("Number of sectors:",S$NS,"\n")
+  cat("Expected loss:",fo(S$EL),"(analytical);",fo(S$EL.crp),"(discretized)\n")
+  cat("      SD loss:",fo(S$SD),"(analytical);",fo(S$SD.crp),"(discretized)\n")
+  cat("Systematic SD:",fo(sqrt(S$SIGMA.SYST)),". Diversifiable SD:",fo(sqrt(S$SIGMA.DIV)),"\n")
+  cat("alpha:",S$ALPHA,"\n")
+  cat("   EC:",fo(S$EC),"\n")
+  cat("  VaR:",fo(S$VaR),"\n")
+  cat("   ES:",fo(S$ES),"\n")
+  cat("Loss unit:",fo(S$LOSS.UNIT),"\n")
+  if(S$NITER.MAX<1)
+    cat("Maximum level of cdf:",S$NITER.MAX,"\n")
+  else
+    cat("Maximum number of iterations for loss distribution:",fo(S$NITER.MAX),"\n")
+  cat("Calculation of risk contributions:",object@CALC.RISK.CONT,"\n")
+  
+})
+
+
+
+
   
 
 setGeneric("get.PATH.IN",function(this) standardGeneric("get.PATH.IN"))
